@@ -391,6 +391,8 @@ clear_old_model (GladeXML  *dialog,
       g_object_unref (model);
     }
 
+  g_object_unref (client);
+
   model = (GtkTreeModel *) gtk_tree_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER);
   
   sort_model = gtk_tree_model_sort_new_with_model (model);
@@ -425,13 +427,17 @@ static gboolean
 should_show_key (const KeyListEntry *entry)
 {
   gint workspaces;
-  
+  GConfClient *client;
+ 
   switch (entry->visibility) {
   case ALWAYS_VISIBLE:
     return TRUE;
   case N_WORKSPACES_GT:
-    workspaces = gconf_client_get_int (gconf_client_get_default (),
+    client = gconf_client_get_default();
+    workspaces = gconf_client_get_int (client,
 				       "/apps/metacity/general/num_workspaces", NULL);
+    g_object_unref (client);
+
     if (workspaces > entry->data)
       return TRUE;
     else
@@ -544,6 +550,8 @@ append_keys_to_tree (GladeXML           *dialog,
       gconf_schema_free (schema);
     }
 
+  g_object_unref (client);
+
   if (i == 0)
       gtk_widget_hide (WID ("shortcuts_vbox"));
   else
@@ -770,6 +778,21 @@ real_start_editing_cb (IdleData *idle_data)
   return FALSE;
 }
 
+static gboolean
+start_editing_kb_cb (GtkTreeView *treeview, 
+			  GtkTreePath *path, 
+			  GtkTreeViewColumn *column,
+			  gpointer user_data)
+{
+  gtk_widget_grab_focus (GTK_WIDGET (treeview));
+  gtk_tree_view_set_cursor (treeview,
+			    path,
+			    gtk_tree_view_get_column (treeview, 1),
+			    TRUE);
+
+  return FALSE;
+}
+
 static gboolean
 start_editing_cb (GtkTreeView    *tree_view,
 		  GdkEventButton *event,
@@ -827,6 +850,9 @@ setup_dialog (GladeXML *dialog)
   g_signal_connect (GTK_TREE_VIEW (WID ("shortcut_treeview")),
 		    "button_press_event",
 		    G_CALLBACK (start_editing_cb), dialog),
+	g_signal_connect (GTK_TREE_VIEW (WID ("shortcut_treeview")),
+	      "row-activated",
+		    G_CALLBACK (start_editing_kb_cb), dialog),
 		    
   column = gtk_tree_view_column_new_with_attributes (_("Action"),
 						     gtk_cell_renderer_text_new (),
@@ -866,6 +892,7 @@ setup_dialog (GladeXML *dialog)
 			   "/apps/metacity/general/num_workspaces",
 			   (GConfClientNotifyFunc) &key_entry_controlling_key_changed,
 			   dialog, NULL, NULL);
+  g_object_unref (client);
 
   /* set up the dialog */
   reload_key_entries (wm_common_get_current_window_manager(), dialog);
